@@ -37,7 +37,7 @@
 #define __BYTE_ORDER    __LITTLE_ENDIAN
 #endif
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 #ifdef  _PACKED
 #pragma pack(1)
@@ -1602,5 +1602,4 @@ void AudioFile::getPosition(char *timestamp, size_t size)
     toTimestamp(pos * info.framing, timestamp, size);
 }
 
-
-
+} // namespace ucommon
