@@ -52,8 +52,6 @@
  * Frequency tolerance +- 1.5% will detect, +-3.5% will reject
  */
 
-using namespace UCOMMON_NAMESPACE;
-
 #define SAMPLE_RATE     8000.0
 
 #define DTMF_THRESHOLD      8.0e7
@@ -66,6 +64,8 @@ using namespace UCOMMON_NAMESPACE;
 #define DTMF_2ND_HARMONIC_ROW   2.5     /* 4dB normal */
 #define DTMF_2ND_HARMONIC_COL   63.1    /* 18dB */
 
+namespace ucommon {
+
 DTMFDetect::DTMFDetect()
 {
     int i;
@@ -380,4 +380,4 @@ int DTMFDetect::getResult(char *buf, int max)
     return  max;
 }
 
-
+} // namespace ucommon
