@@ -21,7 +21,7 @@
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 DTMFTones::DTMFTones(const char *d, Level l, timeout_t duration, timeout_t timer) :
 AudioTone(duration)
@@ -319,3 +319,5 @@ Audio::Linear MFTones::getFrame(void)
         }
     }
 }
+
+} // namespace ucommon
